@@ -51,6 +51,8 @@ module Sass
         ':' => :colon,
         '(' => :lparen,
         ')' => :rparen,
+        '[' => :lsquare,
+        ']' => :rsquare,
         ',' => :comma,
         'and' => :and,
         'or' => :or,
@@ -366,8 +368,17 @@ MESSAGE
         # IDs in properties are used in the Basic User Interface Module
         # (http://www.w3.org/TR/css3-ui/).
         return unless scan(REGULAR_EXPRESSIONS[:id])
-        if @scanner[0] =~ /^\#[0-9a-fA-F]+$/ && (@scanner[0].length == 4 || @scanner[0].length == 7)
-          return [:color, Script::Value::Color.from_hex(@scanner[0])]
+        if @scanner[0] =~ /^\#[0-9a-fA-F]+$/
+          if @scanner[0].length == 4 || @scanner[0].length == 7
+            return [:color, Script::Value::Color.from_hex(@scanner[0])]
+          elsif @scanner[0].length == 5 || @scanner[0].length == 9
+            filename = @options[:filename]
+            Sass::Util.sass_warn <<MESSAGE
+DEPRECATION WARNING on line #{line}, column #{offset}#{" of #{filename}" if filename}:
+The value "#{@scanner[0]}" is currently parsed as a string, but it will be parsed as a color in
+future versions of Sass. Use "unquote('#{@scanner[0]}')" to continue parsing it as a string.
+MESSAGE
+          end
         end
         [:ident, @scanner[0]]
       end
@@ -382,6 +393,15 @@ MESSAGE
       def selector
         start_pos = source_position
         return unless scan(REGULAR_EXPRESSIONS[:selector])
+
+        if @scanner.peek(1) == '&'
+          filename = @options[:filename]
+          Sass::Util.sass_warn <<MESSAGE
+WARNING on line #{line}, column #{offset}#{" of #{filename}" if filename}:
+In Sass, "&&" means two copies of the parent selector. You probably want to use "and" instead.
+MESSAGE
+        end
+
         script_selector = Script::Tree::Selector.new
         script_selector.source_range = range(start_pos)
         [:selector, script_selector]
