@@ -17,15 +17,16 @@ module Sass::Script::Value
     # @private
     #
     # Convert a ruby integer to a rgba components
-    # @param color [Fixnum]
-    # @return [Array<Fixnum>] Array of 4 numbers representing r,g,b and alpha
+    # @param color [Integer]
+    # @return [Array<Integer>] Array of 4 numbers representing r,g,b and alpha
     def self.int_to_rgba(color)
       rgba = (0..3).map {|n| color >> (n << 3) & 0xff}.reverse
       rgba[-1] = rgba[-1] / 255.0
       rgba
     end
 
-    ALTERNATE_COLOR_NAMES = Sass::Util.map_vals({
+    ALTERNATE_COLOR_NAMES = Sass::Util.map_vals(
+      {
         'aqua'                 => 0x00FFFFFF,
         'darkgrey'             => 0xA9A9A9FF,
         'darkslategrey'        => 0x2F4F4FFF,
@@ -35,10 +36,11 @@ module Sass::Script::Value
         'lightgrey'            => 0xD3D3D3FF,
         'lightslategrey'       => 0x778899FF,
         'slategrey'            => 0x708090FF,
-    }, &method(:int_to_rgba))
+      }, &method(:int_to_rgba))
 
     # A hash from color names to `[red, green, blue]` value arrays.
-    COLOR_NAMES = Sass::Util.map_vals({
+    COLOR_NAMES = Sass::Util.map_vals(
+      {
         'aliceblue'            => 0xF0F8FFFF,
         'antiquewhite'         => 0xFAEBD7FF,
         'aquamarine'           => 0x7FFFD4FF,
@@ -179,7 +181,7 @@ module Sass::Script::Value
         'whitesmoke'           => 0xF5F5F5FF,
         'yellow'               => 0xFFFF00FF,
         'yellowgreen'          => 0x9ACD32FF
-     }, &method(:int_to_rgba))
+      }, &method(:int_to_rgba))
 
     # A hash from `[red, green, blue, alpha]` value arrays to color names.
     COLOR_NAMES_REVERSE = COLOR_NAMES.invert.freeze
@@ -232,12 +234,12 @@ module Sass::Script::Value
           raise ArgumentError.new("Color.new(array) expects a three- or four-element array")
         end
 
-        red, green, blue = attrs[0...3].map {|c| c.round}
+        red, green, blue = attrs[0...3].map {|c| Sass::Util.round(c)}
         @attrs = {:red => red, :green => green, :blue => blue}
         @attrs[:alpha] = attrs[3] ? attrs[3].to_f : 1
         @representation = representation
       else
-        attrs = attrs.reject {|k, v| v.nil?}
+        attrs = attrs.reject {|_k, v| v.nil?}
         hsl = [:hue, :saturation, :lightness] & attrs.keys
         rgb = [:red, :green, :blue] & attrs.keys
         if !allow_both_rgb_and_hsl && !hsl.empty? && !rgb.empty?
@@ -258,7 +260,7 @@ module Sass::Script::Value
 
       [:red, :green, :blue].each do |k|
         next if @attrs[k].nil?
-        @attrs[k] = Sass::Util.restrict(@attrs[k].round, 0..255)
+        @attrs[k] = Sass::Util.restrict(Sass::Util.round(@attrs[k]), 0..255)
       end
 
       [:saturation, :lightness].each do |k|
@@ -291,7 +293,7 @@ module Sass::Script::Value
 
     # The red component of the color.
     #
-    # @return [Fixnum]
+    # @return [Integer]
     def red
       hsl_to_rgb!
       @attrs[:red]
@@ -299,7 +301,7 @@ module Sass::Script::Value
 
     # The green component of the color.
     #
-    # @return [Fixnum]
+    # @return [Integer]
     def green
       hsl_to_rgb!
       @attrs[:green]
@@ -307,7 +309,7 @@ module Sass::Script::Value
 
     # The blue component of the color.
     #
-    # @return [Fixnum]
+    # @return [Integer]
     def blue
       hsl_to_rgb!
       @attrs[:blue]
@@ -340,7 +342,7 @@ module Sass::Script::Value
     # The alpha channel (opacity) of the color.
     # This is 1 unless otherwise defined.
     #
-    # @return [Fixnum]
+    # @return [Integer]
     def alpha
       @attrs[:alpha].to_f
     end
@@ -355,7 +357,7 @@ module Sass::Script::Value
 
     # Returns the red, green, and blue components of the color.
     #
-    # @return [Array<Fixnum>] A frozen three-element array of the red, green, and blue
+    # @return [Array<Integer>] A frozen three-element array of the red, green, and blue
     #   values (respectively) of the color
     def rgb
       [red, green, blue].freeze
@@ -363,7 +365,7 @@ module Sass::Script::Value
 
     # Returns the red, green, blue, and alpha components of the color.
     #
-    # @return [Array<Fixnum>] A frozen four-element array of the red, green,
+    # @return [Array<Integer>] A frozen four-element array of the red, green,
     #   blue, and alpha values (respectively) of the color
     def rgba
       [red, green, blue, alpha].freeze
@@ -371,7 +373,7 @@ module Sass::Script::Value
 
     # Returns the hue, saturation, and lightness components of the color.
     #
-    # @return [Array<Fixnum>] A frozen three-element array of the
+    # @return [Array<Integer>] A frozen three-element array of the
     #   hue, saturation, and lightness values (respectively) of the color
     def hsl
       [hue, saturation, lightness].freeze
@@ -379,7 +381,7 @@ module Sass::Script::Value
 
     # Returns the hue, saturation, lightness, and alpha components of the color.
     #
-    # @return [Array<Fixnum>] A frozen four-element array of the hue,
+    # @return [Array<Integer>] A frozen four-element array of the hue,
     #   saturation, lightness, and alpha values (respectively) of the color
     def hsla
       [hue, saturation, lightness, alpha].freeze
@@ -421,7 +423,7 @@ module Sass::Script::Value
     # @return [Color] The new Color object
     # @raise [ArgumentError] if both RGB and HSL keys are specified
     def with(attrs)
-      attrs = attrs.reject {|k, v| v.nil?}
+      attrs = attrs.reject {|_k, v| v.nil?}
       hsl = !([:hue, :saturation, :lightness] & attrs.keys).empty?
       rgb = !([:red, :green, :blue] & attrs.keys).empty?
       if hsl && rgb
@@ -561,6 +563,11 @@ module Sass::Script::Value
     def to_s(opts = {})
       return smallest if options[:style] == :compressed
       return representation if representation
+
+      # IE10 doesn't properly support the color name "transparent", so we emit
+      # generated transparent colors as rgba(0, 0, 0, 0) in favor of that. See
+      # #1782.
+      return rgba_str if Number.basically_equal?(alpha, 0)
       return name if name
       alpha? ? rgba_str : hex_str
     end
@@ -598,16 +605,32 @@ module Sass::Script::Value
       "##{red}#{green}#{blue}"
     end
 
+    def operation_name(operation)
+      case operation
+      when :+
+        "add"
+      when :-
+        "subtract"
+      when :*
+        "multiply"
+      when :/
+        "divide"
+      when :%
+        "modulo"
+      end
+    end
+
     def piecewise(other, operation)
       other_num = other.is_a? Number
       if other_num && !other.unitless?
         raise Sass::SyntaxError.new(
-          "Cannot add a number with units (#{other}) to a color (#{self}).")
+          "Cannot #{operation_name(operation)} a number with units (#{other}) to a color (#{self})."
+        )
       end
 
       result = []
       (0...3).each do |i|
-        res = rgb[i].send(operation, other_num ? other.value : other.rgb[i])
+        res = rgb[i].to_f.send(operation, other_num ? other.value : other.rgb[i])
         result[i] = [[res, 255].min, 0].max
       end
 
@@ -632,7 +655,7 @@ module Sass::Script::Value
         hue_to_rgb(m1, m2, h + 1.0 / 3),
         hue_to_rgb(m1, m2, h),
         hue_to_rgb(m1, m2, h - 1.0 / 3)
-      ].map {|c| (c * 0xff).round}
+      ].map {|c| Sass::Util.round(c * 0xff)}
     end
 
     def hue_to_rgb(m1, m2, h)
